local fn = vim.fn
local packer_bootstrap = false
local install_path = fn.stdpath('data') .. "/site/pack/packer/opt/packer.nvim"

if fn.empty(fn.glob(install_path)) > 0 then
    vim.api.nvim_echo({ {"Installing packer.nvim", "Type" } }, true, {})
    packer_bootstrap = fn.system({'git', 'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
end

vim.cmd([[ packadd packer.nvim ]])
vim.api.nvim_create_autocmd("BufWritePost", {
    pattern = "init.lua",
    command = "source <afile> | PackerCompile",
})


require('packer').startup(function(use)
    use { "wbthomason/packer.nvim", opt = true }
    use { "nvim-lua/plenary.nvim" }
    use {
        "lewis6991/gitsigns.nvim",
        config = function()
            require('gitsigns').setup()
        end
    }
    use { "catppuccin/nvim", as = "catppuccin",
        config = function()
            vim.g.catppuccin_flavour = "frappe"
            require("catppuccin").setup({

                transparent_background = true,
                integrations = {
                    gitsigns = true
                }
            })

            vim.cmd([[ colorscheme catppuccin ]])
        end
    }


    if packer_bootstrap then
        require('packer').sync()
    end
end)

vim.o.sw = 4
vim.o.ts = 4
vim.o.sts = 4
vim.o.expandtab = true
vim.o.compatible = false

vim.cmd([[
  syntax on
  autocmd FileType make set noexpandtab shiftwidth=8 tabstop=8 softtabstop=0
  set bs=indent
  set number
]])

